# Mod9 ASR Python SDK

The *Mod9 ASR Python SDK* is a higher-level interface than the protocol described in the [TCP reference](https://mod9.io/tcp) documentation for the Mod9 ASR Engine.
This software is designed as a compatible drop-in replacement for:

- [Google Cloud STT Python Client Library](https://cloud.google.com/speech-to-text/docs/libraries#client-libraries-install-python),
- [Google Cloud STT REST API](https://cloud.google.com/speech-to-text/docs/reference/rest).

For tutorials, please refer to the documentation at
[mod9.io/python](https://mod9.io/python)
and
[mod9.io/rest](https://mod9.io/rest).

To install the Mod9 ASR Python SDK, if an Internet connection is available:
```
pip3 install mod9-asr
```

Alternatively, to install it from a local source distribution, for example:
```
tar xzf mod9-asr-$VERSION.tar.gz
pip3 install ./mod9-asr-$VERSION
```
